@@ -12,7 +12,7 @@
 ##################################################################
 
 Version = '2.1'
-Build = '1'
+Build = '3'
 
 import sys
 import os
@@ -24,13 +24,13 @@ from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 from PyQt4.QtMaemo5 import *
 
+from clevenStartupUI import *
 from clevenMainUI import *
+from clevenCaptureUI import *
 from clevenDriversUI import *
-from clevenManageCapturedUI import *
 from clevenDictionaryUI import *
 from clevenKeysUI import *
-from clevenStartupUI import *
-from clevenCaptureUI import *
+from clevenManageCapturedUI import *
 
 pathMain             = '/opt/cleven'                        # main path of files
 pathTemp             = '/home/user/.cleven'                 # temp path of files
@@ -717,7 +717,7 @@ class clevenAbout(QtGui.QMainWindow):
        <br><br>It provides the ability to easily configure the injection drivers, scan for surrounding stations, and by using injection and authentication or deauthentication, capture Identification Vector keys. 
        <br><br>In addition, it provides interfaces to decrypt the captured files and manage the keys from successful attacks. 
        <br><br><b>DISCLAIMER:</b> 
-       <br>This program is intended for learning purposes only. I do not condone hacking and would not be held responsible for your actions. Only you would face legal consequences if you used this application for illegal activities. 
+       <br>The application provided is to be used for educational purposes only. The application creator is in no way responsible for any misuse of the information provided. All of the information in this application is meant to help develop a hacker defence attitude in order to prevent the attacks discussed. In no way should you use the information to cause any kind of damage directly or indirectly. The word "Hack" or "Hacking" should be regarded as "Ethical Hack" or "Ethical Hacking" respectively. You implement the information given at your own risk. 
        <br><br>Additional information on the usage, settings and implications can be found in the wiki pages (see buttons in the end). 
        <br><br><b>THANKS TO:</b> 
        <br><br><b>David Gnedt</b> (lxp) for the development of the bleeding-edge wlan drivers. You can support his work by sending him your donations. See for more info: http://david.gnedt.eu/blog/wl1251/ 
@@ -769,7 +769,7 @@ class clevenStartup(QtGui.QDialog):
        if self.step >= 100:
           self.timer.stop()
           self.close()
-       self.step = self.step + 2
+       self.step = self.step + 1
        self.ui.progressBarStart.setValue(self.step)
     
 class clevenMain():
